Público em Geral / Nota Fiscal Eletrônica / Consulta Completa da NFC-e

CONSULTA DA NFC-e
| SAULO PAPALIA DA SILVA
CNPJ: 27.803.795/0001-22 Inscrição Estadual: 1090394842
RUA PREFEITO EVANDRO BEHR, 6755, CAMOBI, Santa Maria, RS
DANFE NFC-e - Documento Auxiliar da Nota Fiscal Eletrônica para Consumidor Final - Via Consumidor
NFC-e não permite aproveitamento de crédito de ICMS
Emissão normal
NFC-e nº: 55929 Série: 1 Data de Emissão: 21/11/2019 14:14:21
Consulte pela Chave de Acesso em https://www.sefaz.rs.gov.br/NFCE
CHAVE DE ACESSO
4319 1127 8037 9500 0122 6500 1000 0559 2911 6674 0439
Protocolo de Autorização: 143191607485312
CONSUMIDOR
Consumidor não identificado
Código | Descrição | Qtde | Un | Vl Unit | Vl Total
823 | BUFFET KG DIA DE SEMANA | 0,315 | KG | 39,9 | 12,56
823 | BUFFET KG DIA DE SEMANA | 0,52 | KG | 39,9 | 20,74
940 | SUCO NATURAL | 1 | UN | 5 | 5,00
Valor total R$ | 38,30
Valor descontos R$ | 0,00
FORMA PAGAMENTO | VALOR PAGO R$
| NaN
Versão XSLT: 1.10

Administração Tributária: | Receita Estadual RS
Data/Hora da Consulta: | 11/08/2020 12:32:37